import React from 'react';
import { Icon, Tabs, Table, Tooltip, Modal, message, Spin, Upload, Input, InputNumber, Select, DatePicker, Button, Radio, Form, Cascader, Tag } from 'antd';
import moment from 'moment';
import './techAchievement.less';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import { IndustryObject, getIndustryCategory } from '../../DicIndustryList.js';
import { beforeUploadFile, splitUrl, getAchievementCategory, getDemandType } from '../../tools.js';

const KeyWordTagGroup = React.createClass({
    getInitialState() {
        return {
            tags: [],
            inputVisible: false,
            inputValue: ''
        };
    },
    handleClose(removedTag) {
        const tags = this.state.tags.filter(tag => tag !== removedTag);
        this.props.tagsArr(tags);
        this.setState({ tags });
    },
    showInput() {
        this.setState({ inputVisible: true }, () => this.input.focus());
    },
    handleInputChange(e) {
        this.setState({ inputValue: e.target.value });
    },
    handleInputConfirm() {
        const state = this.state;
        const inputValue = state.inputValue;
        let tags = state.tags;
        if (inputValue && tags.indexOf(inputValue) === -1 && inputValue.replace(/(^\s*)|(\s*$)/g, "").length != 0) {
            tags = [...tags, inputValue.replace(/(^\s*)|(\s*$)/g, "")];
        }
        this.props.tagsArr(tags);
        this.setState({
            tags,
            inputVisible: false,
            inputValue: '',
        });
    },
    componentWillMount() {
        this.state.tags = this.props.keyWordArr;
    },
    componentWillReceiveProps(nextProps) {
        if (this.props.keyWordArr != nextProps.keyWordArr) {
            this.state.tags = nextProps.keyWordArr;
        };
    },
    render() {
        const { tags, inputVisible, inputValue } = this.state;
        return (
            <div className="keyWord-tips">
                {tags.map((tag, index) => {
                    const isLongTag = tag.length > 10;
                    const tagElem = (
                        <Tag key={tag} closable={index !== -1} afterClose={() => this.handleClose(tag)}>
                            {isLongTag ? `${tag.slice(0, 10)}...` : tag}
                        </Tag>
                    );
                    return isLongTag ? <Tooltip title={tag}>{tagElem}</Tooltip> : tagElem;
                })}
                {inputVisible && (
                    <Input
                        ref={input => this.input = input}
                        type="text"
                        style={{ width: 78 }}
                        value={inputValue}
                        onChange={this.handleInputChange}
                        onBlur={this.handleInputConfirm}
                        onPressEnter={this.handleInputConfirm}
                    />
                )}
                {!inputVisible && <Button className="addtips" type="dashed" disabled={tags.length > 9 ? true : false} onClick={this.showInput}>+ 新关键词</Button>}
            </div>
        );
    }
});

const PicturesWall = React.createClass({
    getInitialState() {
        return {
            previewVisible: false,
            previewImage: '',
            fileList: [],
        }
    },
    handleCancel() {
        this.setState({ previewVisible: false })
    },
    handlePreview(file) {
        this.setState({
            previewImage: file.url || file.thumbUrl,
            previewVisible: true,
        });
    },
    handleChange(info) {
        let fileList = info.fileList;
        this.setState({ fileList });
        this.props.fileList(fileList);
    },
    componentWillReceiveProps(nextProps) {
        this.state.fileList = nextProps.pictureUrl;
    },
    render() {
        const { previewVisible, previewImage, fileList } = this.state;
        const uploadButton = (
            <div>
                <Icon type="plus" />
                <div className="ant-upload-text">点击上传</div>
            </div>
        );
        return (
            <div className="clearfix">
                <Upload
                    action={globalConfig.context + "/api/user/achievement/uploadPicture"}
                    data={{ 'sign': this.props.pictureSign }}
                    listType="picture-card"
                    fileList={fileList}
                    onPreview={this.handlePreview}
                    onChange={this.handleChange} >
                    {fileList.length >= 5 ? null : uploadButton}
                </Upload>
                <Modal maskClosable={false} visible={previewVisible} footer={null} onCancel={this.handleCancel}>
                    <img alt="example" style={{ width: '100%' }} src={previewImage} />
                </Modal>
            </div>
        );
    }
});

const AchievementDetailShow = Form.create()(React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false,
            textFileList: [],
            techPlanFileList: [],
            businessPlanFileList: [],
            maturityPictureUrl: [],
            technicalPictureUrl: [],
            tags: []
        };
    },
    loadData(id) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + (window.userData.type == "1" ? "/api/user/achievement/orgDetail" : "/api/user/achievement/userDetail"),
            data: {
                id: id
            },
            success: function (data) {
                let thisData = data.data;
                if (!thisData) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                    thisData = {};
                };
                this.setState({
                    data: thisData,
                    tags: thisData.keyword ? thisData.keyword.split(",") : [],
                    technicalPictureUrl: thisData.technicalPictureUrl ? splitUrl(thisData.technicalPictureUrl, ',', globalConfig.avatarHost + '/upload') : [],
                    maturityPictureUrl: thisData.maturityPictureUrl ? splitUrl(thisData.maturityPictureUrl, ',', globalConfig.avatarHost + '/upload') : []
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    offShelf() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/achievement/offShelf",
            data: { "id": this.props.data.id }
        }).done(function (data) {
            this.setState({
                loading: false
            });
            if (!data.error.length) {
                message.success('撤销成功！');
                this.setState({
                    visible: false,
                    releaseSubmitVisible: false
                });
                this.props.handleOk();
            } else {
                message.warning(data.error[0].message);
            }
        }.bind(this));
    },
    componentWillMount() {
        if (this.props.data.id) {
            this.loadData(this.props.data.id);
        } else {
            this.state.data = {};
        };
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.state.textFileList = [];
            this.state.techPlanFileList = [];
            this.state.businessPlanFileList = [];
            if (nextProps.data.id) {
                this.loadData(nextProps.data.id);
            } else {
                this.state.data = {};
                this.state.tags = [];
                this.state.maturityPictureUrl = [];
                this.state.technicalPictureUrl = [];
            };
            this.props.form.resetFields();
        };
    },
    render() {
        const theData = this.state.data || {};
        const { getFieldDecorator } = this.props.form;
        const FormItem = Form.Item
        const formItemLayout = {
            labelCol: { span: 8 },
            wrapperCol: { span: 14 },
        };
        return (
            <Form horizontal onSubmit={this.handleSubmit} id="demand-form">
                <Spin spinning={this.state.loading}>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="编号" >
                            <span>{theData.serialNumber}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="名称" >
                            <span>{theData.name}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="数据类别" >
                            {(() => {
                                switch (theData.dataCategory) {
                                    case "0":
                                        return <span>成果</span>;
                                    case "1":
                                        return <span>技术</span>;
                                    case "2":
                                        return <span>项目</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="类型" >
                            <span>{getAchievementCategory(theData.category)}</span>
                        </FormItem>
                    </div>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="是否发布" >
                            {(() => {
                                switch (theData.releaseStatus) {
                                    case "0":
                                        return <span>未发布</span>;
                                    case "1":
                                        return <div>
                                            <span>已发布</span>
                                            <Button style={{ marginLeft: '10px' }} onClick={() => { this.setState({ releaseSubmitVisible: true }); }}>撤消发布</Button>
                                            <Modal maskClosable={false} title="确认"
                                                visible={this.state.releaseSubmitVisible}
                                                width='300px'
                                                footer={null}
                                                onCancel={() => { this.setState({ releaseSubmitVisible: false }) }} >
                                                <span>确认要撤销发布吗？</span>
                                                <Button className="modal-submit" type="primary" onClick={this.offShelf} >确认</Button>
                                                <Button className="modal-submit" type="ghost" onClick={() => { this.setState({ releaseSubmitVisible: false }) }}>取消</Button>
                                            </Modal>
                                        </div>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="发布时间" >
                            <span>{theData.releaseDateFormattedDate}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="审核状态" >
                            {(() => {
                                switch (theData.auditStatus) {
                                    case "0":
                                        return <span>未提交审核(草稿)</span>;
                                    case "1":
                                        return <span>提交审核</span>;
                                    case "2":
                                        return <span>审核中</span>;
                                    case "3":
                                        return <span>审核通过</span>;
                                    case "4":
                                        return <span>审核未通过</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="关键词" >
                        {this.state.tags.map((tag) => {
                            return <Tooltip key={tag} title={tag}>
                                <Tag key={tag}>{tag}</Tag>
                            </Tooltip>;
                        })}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="摘要" >
                        <span>{theData.summary}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成果简介" >
                        <span>{theData.introduction}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术图片" >
                        <div className="clearfix">
                            <Upload className="demandDetailShow-upload"
                                listType="picture-card"
                                fileList={this.state.technicalPictureUrl}
                                onPreview={(file) => {
                                    this.setState({
                                        previewImage: file.url || file.thumbUrl,
                                        previewVisible: true,
                                    });
                                }} >
                            </Upload>
                            <Modal maskClosable={false} footer={null}
                                visible={this.state.previewVisible}
                                onCancel={() => { this.setState({ previewVisible: false }) }}>
                                <img alt="" style={{ width: '100%' }} src={this.state.previewImage || ''} />
                            </Modal>
                        </div>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="应用领域" >
                        <span>{getIndustryCategory(theData.fieldA, theData.fieldB)}</span>
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="成熟度" >
                            {(() => {
                                switch (theData.maturity) {
                                    case "0":
                                        return <span>正在研发</span>;
                                    case "1":
                                        return <span>已有样品</span>;
                                    case "2":
                                        return <span>通过小试</span>;
                                    case "3":
                                        return <span>通过中试</span>;
                                    case "4":
                                        return <span>可以量产</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="创新度" >
                            {(() => {
                                switch (theData.innovation) {
                                    case "0":
                                        return <span>行业先进</span>;
                                    case "1":
                                        return <span>行业领先</span>;
                                    case "2":
                                        return <span>国内先进</span>;
                                    case "3":
                                        return <span>国内领先</span>;
                                    case "4":
                                        return <span>国际先进</span>;
                                    case "5":
                                        return <span>国际领先</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成熟度证明材料(图片)" >
                        <Upload className="demandDetailShow-upload"
                            listType="picture-card"
                            fileList={this.state.maturityPictureUrl}
                            onPreview={(file) => {
                                this.setState({
                                    previewImage: file.url || file.thumbUrl,
                                    previewVisible: true,
                                });
                            }} >
                        </Upload>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="成熟度证明材料(文本)" >
                        <p>{theData.maturityTextFileUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_maturity_text_file') }}>成熟度证明材料(文本文件)</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成熟度证明材料(视频地址)" >
                        <span>{theData.maturityVideoUrl}</span>
                    </FormItem>
                    <div className="clearfix" >
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="成果所有人名称" >
                            <span>{theData.iOwnerName || theData.ownerName}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所有人证件号" >
                            <span>{theData.iOwnerIdNumber || theData.ownerIdNumber}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所有人联系电话" >
                            <span>{theData.iOwnerMobile || theData.ownerMobile}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所有人电子邮箱" >
                            <span>{theData.iOwnerEmail || theData.ownerEmail}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所有人通信地址" >
                            <span>{theData.iOwnerPostalAddress || theData.ownerPostalAddress}</span>
                        </FormItem>
                    </div>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所有人类型" >
                            {(() => {
                                switch (theData.ownerType) {
                                    case "0":
                                        return <span>个人</span>;
                                    case "1":
                                        return <span>组织</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    {theData.ownerType == "9" ? <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所属组织名称" >
                            <span>{theData.orgName}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所属组织地址" >
                            <span>{theData.orgAddress}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所属组织邮箱" >
                            <span>{theData.orgEmail}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所属组织联系人名称" >
                            <span>{theData.orgContacts}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="所属组织联系人电话" >
                            <span>{theData.orgContactsMobile}</span>
                        </FormItem>
                    </div> : <div></div>}
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="合作方式" >
                            {(() => {
                                switch (theData.cooperationMode) {
                                    case "0":
                                        return <span>技术转让</span>;
                                    case "1":
                                        return <span>授权生产</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="转让方式" >
                            {(() => {
                                switch (theData.transferMode) {
                                    case "0":
                                        return <span>完全转让</span>;
                                    case "1":
                                        return <span>许可转让</span>;
                                    case "2":
                                        return <span>技术入股</span>;
                                }
                            })()}
                        </FormItem>
                    </div>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="议价方式" >
                            {(() => {
                                switch (theData.bargainingMode) {
                                    case "0":
                                        return <span>面议</span>;
                                    case "1":
                                        return <span>定价</span>;
                                }
                            })()}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="转让价格" >
                            <span>{theData.transferPrice} 万元</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术场景" >
                        <span>{theData.technicalScene}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术突破" >
                        <span>{theData.breakthrough}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="专利情况" >
                        <span>{theData.patentCase}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="获奖情况" >
                        <span>{theData.awards}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术团队情况" >
                        <span>{theData.teamDes}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术参数" >
                        <span>{theData.parameter}</span>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="技术方案" >
                        <p>{theData.techPlanUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_tech_plan') }}>技术方案</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="商业计划书" >
                        <p>{theData.businessPlanUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_business_plan') }}>商业计划书</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem wrapperCol={{ span: 12, offset: 4 }}>
                        <Button className="set-submit" type="ghost" onClick={this.props.closeDesc}>取消</Button>
                    </FormItem>
                </Spin>
            </Form >
        )
    }
}));

const AchievementDetailForm = Form.create()(React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false,
            auditStatus: 0,
            textFileList: [],
            techPlanFileList: [],
            businessPlanFileList: [],
            maturityPictureUrl: [],
            technicalPictureUrl: [],
            tags: []
        };
    },
    loadData(id) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + (window.userData.type == "1" ? "/api/user/achievement/orgDetail" : "/api/user/achievement/userDetail"),
            data: {
                id: id
            },
            success: function (data) {
                let thisData = data.data;
                if (!thisData) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                    thisData = {};
                };
                this.setState({
                    data: thisData,
                    orgDisplay: thisData.ownerType,
                    tags: thisData.keyword ? thisData.keyword.split(",") : [],
                    technicalPictureUrl: thisData.technicalPictureUrl ? splitUrl(thisData.technicalPictureUrl, ',', globalConfig.avatarHost + '/upload') : [],
                    maturityPictureUrl: thisData.maturityPictureUrl ? splitUrl(thisData.maturityPictureUrl, ',', globalConfig.avatarHost + '/upload') : []
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getTagsArr(e) {
        this.setState({ tags: e });
    },
    getMaturityPictureUrl(e) {
        this.setState({ maturityPictureUrl: e });
    },
    getTechnicalPictureUrl(e) {
        this.setState({ technicalPictureUrl: e });
    },
    handleSubmit(e) {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            //keyword长度判断
            if (this.state.tags.length < 3) {
                message.warning('关键词数量不能小于3个！');
                return;
            };
            //url转化
            let theTechnicalPictureUrl = [];
            if (this.state.technicalPictureUrl.length) {
                let picArr = [];
                this.state.technicalPictureUrl.map(function (item) {
                    picArr.push(item.response.data);
                });
                theTechnicalPictureUrl = picArr.join(",");
            };
            let theMaturityPictureUrl = [];
            if (this.state.maturityPictureUrl.length) {
                let picArr = [];
                this.state.maturityPictureUrl.map(function (item) {
                    picArr.push(item.response.data);
                });
                theMaturityPictureUrl = picArr.join(",");
            };
            if (!err) {
                this.setState({
                    loading: true
                });
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: this.props.data.id ? globalConfig.context + '/api/user/achievement/update' : globalConfig.context + '/api/user/achievement/apply',
                    data: {
                        id: this.props.data.id,
                        dataCategory: values.dataCategory,
                        serialNumber: this.props.data.serialNumber,
                        name: values.name,
                        keyword: this.state.tags ? this.state.tags.join(",") : [],
                        keywords: this.state.tags,
                        category: values.category,
                        summary: values.summary,
                        introduction: values.introduction,
                        technicalPictureUrl: theTechnicalPictureUrl,
                        fieldA: values.field ? values.field[0] : undefined,
                        fieldB: values.field ? values.field[1] : undefined,
                        maturity: values.maturity,
                        maturityPictureUrl: theMaturityPictureUrl,
                        maturityTextFileUrl: this.state.maturityTextFileUrl,
                        maturityVideoUrl: values.maturityVideoUrl,
                        innovation: values.innovation,
                        cooperationMode: values.cooperationMode,
                        transferMode: values.transferMode,
                        bargainingMode: values.bargainingMode,
                        transferPrice: values.transferPrice,
                        technicalScene: values.technicalScene,
                        breakthrough: values.breakthrough,
                        patentCase: values.patentCase,
                        awards: values.awards,
                        teamDes: values.teamDes,
                        parameter: values.parameter,
                        releaseStatus: values.releaseStatus,
                        techPlanUrl: this.state.techPlanUrl,
                        businessPlanUrl: this.state.businessPlanUrl,
                        auditStatus: this.state.auditStatus,

                        ownerType: window.userData.type // 所有人类型
                    }
                }).done(function (data) {
                    this.state.auditStatus = 0;
                    this.setState({
                        loading: false
                    });
                    if (!data.error.length) {
                        message.success('保存成功！');
                        this.props.handleOk();
                    } else {
                        message.warning(data.error[0].message);
                    }
                }.bind(this));
            }
        });
    },
    componentWillMount() {
        if (this.props.data.id) {
            this.loadData(this.props.data.id);
        } else {
            this.state.data = {};
        };
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.state.textFileList = [];
            this.state.techPlanFileList = [];
            this.state.businessPlanFileList = [];
            if (nextProps.data.id) {
                this.loadData(nextProps.data.id);
            } else {
                this.state.data = {};
                this.state.tags = [];
                this.state.maturityPictureUrl = [];
                this.state.technicalPictureUrl = [];
            };
            this.props.form.resetFields();
        };
    },
    render() {
        const theData = this.state.data || {};
        const { getFieldDecorator } = this.props.form;
        const FormItem = Form.Item
        const formItemLayout = {
            labelCol: { span: 8 },
            wrapperCol: { span: 14 },
        };
        return (
            <Form horizontal onSubmit={this.handleSubmit} id="demand-form">
                <Spin spinning={this.state.loading}>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="编号" >
                            <span>{theData.serialNumber}</span>
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="名称" >
                            {getFieldDecorator('name', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.name
                            })(
                                <Input />
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="数据类别" >
                            {getFieldDecorator('dataCategory', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.dataCategory
                            })(
                                <Select placeholder="选择数据类型" style={{ width: 160 }} >
                                    <Select.Option value="0" >成果</Select.Option>
                                    <Select.Option value="1" >技术</Select.Option>
                                    <Select.Option value="2" >项目</Select.Option>
                                </Select>
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="类型" >
                            {getFieldDecorator('category', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.category
                            })(
                                <Select style={{ width: 160 }} placeholder="请选择成果类型">
                                    {this.props.achievementCategoryOption}
                                </Select>
                                )}
                        </FormItem>
                        <div className="clearfix">
                            <FormItem className="half-item"
                                {...formItemLayout}
                                label="是否发布" >
                                {(() => {
                                    switch (theData.releaseStatus) {
                                        case "0":
                                            return <span>未发布</span>;
                                        case "1":
                                            return <span>已发布</span>;
                                    }
                                })()}
                            </FormItem>
                            <FormItem className="half-item"
                                {...formItemLayout}
                                label="发布时间" >
                                <span>{theData.releaseDateFormattedDate}</span>
                            </FormItem>
                            <FormItem className="half-item"
                                {...formItemLayout}
                                label="审核状态" >
                                {(() => {
                                    switch (theData.auditStatus) {
                                        case "0":
                                            return <span>未提交审核(草稿)</span>;
                                        case "1":
                                            return <span>提交审核</span>;
                                        case "2":
                                            return <span>审核中</span>;
                                        case "3":
                                            return <span>审核通过</span>;
                                        case "4":
                                            return <span>审核未通过</span>;
                                    }
                                })()}
                            </FormItem>

                        </div>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="关键词" >
                        <KeyWordTagGroup
                            keyWordArr={this.state.tags}
                            tagsArr={this.getTagsArr}
                            visible={this.props.visible} />
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="摘要" >
                        {getFieldDecorator('summary', {
                            initialValue: theData.summary
                        })(
                            <Input type="textarea" rows={4} />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成果简介" >
                        {getFieldDecorator('introduction', {
                            initialValue: theData.introduction
                        })(
                            <Input type="textarea" rows={4} placeholder="项目成果简介；项目核心创新点；项目详细用途；预期效益说明；主要技术（性能）指标；市场前景；应用范围；发展历程。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术图片" >
                        <PicturesWall
                            pictureSign="achievement_technical_picture"
                            fileList={this.getTechnicalPictureUrl}
                            pictureUrl={this.state.technicalPictureUrl} />
                        <p>图片建议：专利证书或专利申请书图片、技术图纸、样品图片、技术相关网络图片；成熟度处于非研发阶段的项目，必须上传样品图片，如未上传，成熟度将视为处在研发阶段。</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="应用领域" >
                        {getFieldDecorator('field', {
                            rules: [{ type: 'array', required: true, message: '此项为必填项!' }],
                            initialValue: [theData.fieldA, theData.fieldB]
                        })(
                            <Cascader style={{ width: 300 }} options={IndustryObject} placeholder="应用领域" />
                            )}
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="成熟度" >
                            {getFieldDecorator('maturity', {
                                initialValue: theData.maturity
                            })(
                                <Select placeholder="选择成熟度" style={{ width: 160 }} >
                                    <Select.Option value="0" >正在研发</Select.Option>
                                    <Select.Option value="1" >已有样品</Select.Option>
                                    <Select.Option value="2" >通过小试</Select.Option>
                                    <Select.Option value="3" >通过中试</Select.Option>
                                    <Select.Option value="4" >可以量产</Select.Option>
                                </Select>
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="创新度" >
                            {getFieldDecorator('innovation', {
                                initialValue: theData.innovation
                            })(
                                <Select placeholder="选择创新度" style={{ width: 160 }} >
                                    <Select.Option value="0" >行业先进</Select.Option>
                                    <Select.Option value="1" >行业领先</Select.Option>
                                    <Select.Option value="2" >国内先进</Select.Option>
                                    <Select.Option value="3" >国内领先</Select.Option>
                                    <Select.Option value="4" >国际先进</Select.Option>
                                    <Select.Option value="5" >国际领先</Select.Option>
                                </Select>
                                )}
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成熟度证明材料(图片)" >
                        <PicturesWall
                            pictureSign="achievement_maturity_picture"
                            fileList={this.getMaturityPictureUrl}
                            pictureUrl={this.state.maturityPictureUrl} />
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="成熟度证明材料(文本)" >
                        <Upload
                            name="ratepay"
                            action={globalConfig.context + "/api/user/achievement/uploadTextFile"}
                            data={{ 'sign': 'achievement_maturity_text_file' }}
                            beforeUpload={beforeUploadFile}
                            fileList={this.state.textFileList}
                            onChange={(info) => {
                                if (info.file.status !== 'uploading') {
                                    console.log(info.file, info.fileList);
                                }
                                if (info.file.status === 'done') {
                                    if (!info.file.response.error.length) {
                                        message.success(`${info.file.name} 文件上传成功！`);
                                    } else {
                                        message.warning(info.file.response.error[0].message);
                                        return;
                                    };
                                    this.state.maturityTextFileUrl = info.file.response.data;
                                } else if (info.file.status === 'error') {
                                    message.error(`${info.file.name} 文件上传失败。`);
                                };
                                this.setState({ textFileList: info.fileList.slice(-1) });
                            }} >
                            <Button><Icon type="upload" /> 上传需求文本文件 </Button>
                        </Upload>
                        <p style={{ marginTop: '10px' }}>{theData.maturityTextFileUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_maturity_text_file') }}>成熟度证明材料(文本文件)</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="成熟度证明材料(视频地址)" >
                        {getFieldDecorator('maturityVideoUrl', {
                            initialValue: theData.maturityVideoUrl
                        })(
                            <Input />
                            )}
                    </FormItem>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="合作方式" >
                            {getFieldDecorator('cooperationMode', {
                                rules: [{ required: true, message: '此项为必填项!' }],
                                initialValue: theData.cooperationMode
                            })(
                                <Radio.Group>
                                    <Radio value="0">技术转让</Radio>
                                    <Radio value="1">授权生产</Radio>
                                </Radio.Group>
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="转让方式" >
                            {getFieldDecorator('transferMode', {
                                initialValue: theData.transferMode
                            })(
                                <Select placeholder="选择转让方式" style={{ width: 160 }} >
                                    <Select.Option value="0" >完全转让</Select.Option>
                                    <Select.Option value="1" >许可转让</Select.Option>
                                    <Select.Option value="2" >技术入股</Select.Option>
                                </Select>
                                )}
                        </FormItem>
                    </div>
                    <div className="clearfix">
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="议价方式" >
                            {getFieldDecorator('bargainingMode', {
                                initialValue: theData.bargainingMode
                            })(
                                <Radio.Group>
                                    <Radio value="0">面议</Radio>
                                    <Radio value="1">定价</Radio>
                                </Radio.Group>
                                )}
                        </FormItem>
                        <FormItem className="half-item"
                            {...formItemLayout}
                            label="转让价格" >
                            {getFieldDecorator('transferPrice', {
                                initialValue: theData.transferPrice
                            })(
                                <InputNumber min={0} max={999999} step={0.01} />
                                )}
                            <span style={{ marginLeft: '20px' }}>万元</span>
                        </FormItem>
                    </div>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术场景" >
                        {getFieldDecorator('technicalScene', {
                            initialValue: theData.technicalScene
                        })(
                            <Input type="textarea" rows={2} placeholder="说明解决了什么问题。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术突破" >
                        {getFieldDecorator('breakthrough', {
                            initialValue: theData.breakthrough
                        })(
                            <Input type="textarea" rows={2} placeholder="说明该技术成果突破性的研究。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="专利情况" >
                        {getFieldDecorator('patentCase', {
                            initialValue: theData.patentCase
                        })(
                            <Input type="textarea" rows={2} placeholder="一个“技术”可能由多个专利构成，需要说明技术-专利的关系。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="获奖情况" >
                        {getFieldDecorator('awards', {
                            initialValue: theData.awards
                        })(
                            <Input type="textarea" rows={2} placeholder="一个“技术”可能存在社会奖励情况，需要说明社会奖励情况。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术团队情况" >
                        {getFieldDecorator('teamDes', {
                            initialValue: theData.teamDes
                        })(
                            <Input type="textarea" rows={2} placeholder="一个“技术”、“项目”可能存在团队，需要说明团队情况。" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 18 }}
                        label="技术参数" >
                        {getFieldDecorator('parameter', {
                            initialValue: theData.parameter
                        })(
                            <Input type="textarea" rows={2} placeholder="描述技术参数信息" />
                            )}
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="技术方案" >
                        <Upload
                            name="ratepay"
                            action={globalConfig.context + "/api/user/achievement/uploadTextFile"}
                            data={{ 'sign': 'achievement_tech_plan' }}
                            beforeUpload={beforeUploadFile}
                            fileList={this.state.techPlanFileList}
                            onChange={(info) => {
                                if (info.file.status !== 'uploading') {
                                    console.log(info.file, info.fileList);
                                }
                                if (info.file.status === 'done') {
                                    if (!info.file.response.error.length) {
                                        message.success(`${info.file.name} 文件上传成功！`);
                                    } else {
                                        message.warning(info.file.response.error[0].message);
                                        return;
                                    };
                                    this.state.techPlanUrl = info.file.response.data;
                                } else if (info.file.status === 'error') {
                                    message.error(`${info.file.name} 文件上传失败。`);
                                };
                                this.setState({ techPlanFileList: info.fileList.slice(-1) });
                            }} >
                            <Button><Icon type="upload" /> 上传技术方案文件 </Button>
                        </Upload>
                        <p style={{ marginTop: '10px' }}>{theData.techPlanUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_tech_plan') }}>技术方案</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem
                        labelCol={{ span: 4 }}
                        wrapperCol={{ span: 6 }}
                        label="商业计划书" >
                        <Upload
                            name="ratepay"
                            action={globalConfig.context + "/api/user/achievement/uploadTextFile"}
                            data={{ 'sign': 'achievement_business_plan' }}
                            beforeUpload={beforeUploadFile}
                            fileList={this.state.businessPlanFileList}
                            onChange={(info) => {
                                if (info.file.status !== 'uploading') {
                                    console.log(info.file, info.fileList);
                                }
                                if (info.file.status === 'done') {
                                    if (!info.file.response.error.length) {
                                        message.success(`${info.file.name} 文件上传成功！`);
                                    } else {
                                        message.warning(info.file.response.error[0].message);
                                        return;
                                    };
                                    this.state.businessPlanUrl = info.file.response.data;
                                } else if (info.file.status === 'error') {
                                    message.error(`${info.file.name} 文件上传失败。`);
                                };
                                this.setState({ businessPlanFileList: info.fileList.slice(-1) });
                            }} >
                            <Button><Icon type="upload" /> 上传商业计划书文件 </Button>
                        </Upload>
                        <p style={{ marginTop: '10px' }}>{theData.businessPlanUrl ?
                            <span className="download-file">
                                <a onClick={() => { window.open(globalConfig.context + '/api/user/achievement/download?id=' + this.props.data.id + '&sign=achievement_business_plan') }}>商业计划书</a>
                            </span>
                            : <span><Icon type="exclamation-circle" style={{ color: '#ffbf00', marginRight: '6px' }} />未上传！</span>}</p>
                    </FormItem>
                    <FormItem wrapperCol={{ span: 12, offset: 4 }}>
                        <Button className="set-submit" type="primary" htmlType="submit">保存</Button>
                        <Button className="set-submit" type="ghost" onClick={(e) => { this.state.auditStatus = 1; }} htmlType="submit">发布</Button>
                        <Button className="set-submit" type="ghost" onClick={this.props.closeDesc}>取消</Button>
                    </FormItem>
                </Spin>
            </Form >
        )
    }
}));

const AchievementDetail = React.createClass({
    getInitialState() {
        return {
            visible: false,
            tabsKey: 1,
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '数据类型',
                    dataIndex: 'dataCategory',
                    key: 'dataCategory',
                    render: text => {
                        switch (text) {
                            case "0":
                                return <span>成果</span>;
                            case "1":
                                return <span>技术</span>;
                            case "2":
                                return <span>项目</span>;
                        }
                    }
                }, {
                    title: '名称',
                    dataIndex: 'name',
                    key: 'name',
                }, {
                    title: '关键字',
                    dataIndex: 'keyword',
                    key: 'keyword',
                }, {
                    title: '类型',
                    dataIndex: 'demandType',
                    key: 'demandType',
                    render: text => { return getDemandType(text); }
                }, {
                    title: '所有人名称',
                    dataIndex: 'theName',
                    key: 'theName',
                }, {
                    title: '发布时间',
                    dataIndex: 'releaseDateFormattedDate',
                    key: 'releaseDateFormattedDate',
                }, {
                    title: '有效期限',
                    dataIndex: 'validityPeriodFormattedDate',
                    key: 'validityPeriodFormattedDate',
                },
            ],
            dataSource: [],
        };
    },
    getTableList() {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/achievement/achievementDemand",
            data: { id: this.props.data.id },
            success: function (data) {
                let theArr = [];
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else if (data.data.length) {
                    for (let i = 0; i < data.data.length; i++) {
                        let thisdata = data.data[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            dataCategory: thisdata.dataCategory,
                            name: thisdata.name,
                            keyword: thisdata.keyword,
                            demandType: thisdata.demandType,
                            theName: thisdata.username || thisdata.unitName,
                            releaseDateFormattedDate: thisdata.releaseDateFormattedDate,
                            validityPeriodFormattedDate: thisdata.validityPeriodFormattedDate
                        });
                    };
                };
                this.setState({
                    dataSource: theArr,
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    tableRowClick(record, index) {
        if (record.ownerType == "0") {
            window.open(globalConfig.context + '/user/account/demand.html?rid=' + record.id + '#techDemandOrg');
        } else if (record.ownerType == "1") {
            window.open(globalConfig.context + '/user/account/demand.html?rid=' + record.id + '#techDemandUser')
        };
    },
    showModal() {
        this.setState({
            visible: true,
        });
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false);
    },
    handleOk(e) {
        this.setState({
            visible: false,
        });
        this.props.closeDesc(false, true);
    },
    componentWillReceiveProps(nextProps) {
        if (nextProps.showDesc) {
            this.state.tabsKey = "1";
            this.state.tabBool = true;
        };
        this.state.visible = nextProps.showDesc;
    },
    render() {
        if (this.props.data) {
            return (
                <div className="patent-desc">
                    <Modal maskClosable={false} visible={this.state.visible}
                        onOk={this.checkPatentProcess} onCancel={this.handleCancel}
                        width='1000px'
                        footer=''
                        className="admin-desc-content">
                        <Tabs activeKey={this.state.tabsKey}
                            onChange={(e) => {
                                this.setState({ tabsKey: e });
                                if (e == "2" && this.state.tabBool) {
                                    this.getTableList();
                                    this.state.tabBool = false;
                                };
                            }} >
                            <Tabs.TabPane tab="成果详情" key="1">
                                {(() => {
                                    if (this.props.data.auditStatus && this.props.data.auditStatus != "0" && this.props.data.auditStatus != "4") {
                                        return <AchievementDetailShow
                                            data={this.props.data}
                                            closeDesc={this.handleCancel}
                                            visible={this.state.visible}
                                            handleOk={this.handleOk} />
                                    } else {
                                        return <AchievementDetailForm
                                            data={this.props.data}
                                            achievementCategoryOption={this.props.achievementCategoryOption}
                                            closeDesc={this.handleCancel}
                                            visible={this.state.visible}
                                            handleOk={this.handleOk} />
                                    }
                                })()}
                            </Tabs.TabPane>
                            <Tabs.TabPane tab="匹配列表" key="2">
                                <Table columns={this.state.columns}
                                    dataSource={this.state.dataSource}
                                    pagination={false}
                                    onRowClick={this.tableRowClick} />
                            </Tabs.TabPane>
                        </Tabs>
                    </Modal>
                </div>
            );
        } else {
            return <div></div>
        }
    },
});

export default AchievementDetail;